@@ -12,19 +12,15 @@ class Utility(APIBase):
     ) -> Response:
         files = {"image1": image1, "image2": image2}
         data = {"result": result}
-        try:
-            return self.client.post(
-                url="/v1/utility/compare/", data=data, files=files
-            )
-        finally:
-            self.client.close()
+
+        return self.client.post(
+            url="/v1/utility/compare/", data=data, files=files
+        )
 
     def asm(self, image: BinaryIO) -> Response:
         files = {"image": image}
-        try:
-            return self.client.post(url="/v1/utility/asm/", files=files)
-        finally:
-            self.client.close()
+
+        return self.client.post(url="/v1/utility/asm/", files=files)
 
 
 class UtilityAsync(APIBaseAsync):
@@ -33,16 +29,12 @@ class UtilityAsync(APIBaseAsync):
     ) -> Response:
         files = {"image1": image1, "image2": image2}
         data = {"result": result}
-        try:
-            return await self.client.post(
-                url="/v1/utility/compare/", data=data, files=files
-            )
-        finally:
-            await self.client.aclose()
+
+        return await self.client.post(
+            url="/v1/utility/compare/", data=data, files=files
+        )
 
     async def asm(self, image: BinaryIO) -> Response:
         files = {"image": image}
-        try:
-            return await self.client.post(url="/v1/utility/asm/", files=files)
-        finally:
-            await self.client.aclose()
+
+        return await self.client.post(url="/v1/utility/asm/", files=files)
