@@ -6,10 +6,8 @@ from neuroio.api.base import APIBase, APIBaseAsync
 class Auth(APIBase):
     def login(self, username: str, password: str) -> Response:
         data = {"username": username, "password": password}
-        try:
-            return self.client.post(url="/v1/login/", json=data)
-        finally:
-            self.client.close()
+
+        return self.client.post(url="/v1/login/", json=data)
 
     def password_change(
         self, old_password: str, new_password: str, reset_tokens: bool = False
@@ -20,19 +18,15 @@ class Auth(APIBase):
             "password2": new_password,
             "reset_tokens": reset_tokens,
         }
-        try:
-            return self.client.post(url="/v1/auth/password/change/", json=data)
-        finally:
-            self.client.close()
+
+        return self.client.post(url="/v1/auth/password/change/", json=data)
 
 
 class AuthAsync(APIBaseAsync):
     async def login(self, username: str, password: str) -> Response:
         data = {"username": username, "password": password}
-        try:
-            return await self.client.post(url="/v1/login/", json=data)
-        finally:
-            await self.client.aclose()
+
+        return await self.client.post(url="/v1/login/", json=data)
 
     async def password_change(
         self, old_password: str, new_password: str, reset_tokens: bool = False
@@ -43,9 +37,7 @@ class AuthAsync(APIBaseAsync):
             "password2": new_password,
             "reset_tokens": reset_tokens,
         }
-        try:
-            return await self.client.post(
-                url="/v1/auth/password/change/", json=data
-            )
-        finally:
-            await self.client.aclose()
+
+        return await self.client.post(
+            url="/v1/auth/password/change/", json=data
+        )
